@@ -15,7 +15,7 @@ pwd=os.path.split(os.path.realpath(__file__))[0]
 sys.path.append(pwd)
 
 
-print('Example: python3 AnnoSINE_v2.py 2 ../Input_Files/test.fasta ../Output_Files', flush=True)
+print('Example: AnnoSINE_v2 3 ../Input_Files/test.fasta ../Output_Files', flush=True)
 parser = argparse.ArgumentParser(description="SINE Annotation Tool for Plant Genomes",
                                  formatter_class=RawTextHelpFormatter)
 
@@ -1507,7 +1507,7 @@ def process_sine_finder(genome_assembly_path, sine_finder_out, out_genome_assemb
                 end_position.append(end-50)
                 seq = output_genome_sequence[seq_id][start:end]
                 finder_seq.append(seq)
-    os.system('mv '+sine_finder_out+' '+out_genome_assembly_path)
+    #os.system('mv '+sine_finder_out+' '+out_genome_assembly_path)
     if pattern == 2 or pattern == 3:
         if os.path.exists(out_genome_assembly_path+'/Step1_extend_tsd_input_2.fa'):
             modify_text(out_genome_assembly_path+'/Step1_extend_tsd_input_2.fa')
@@ -1551,16 +1551,19 @@ def check_finished(pre,arr,at):
         print(pre+' not finished! Will regenerate the result!')
     return a
 
-def convert_ingenome(ingenome):
+def convert_ingenome(ingenome,odir):
     uid=uuid.uuid1().hex
     fdir=os.path.dirname(ingenome)
     ig=os.path.basename(ingenome)
     name, ext = os.path.splitext(ig)
     nf=name+'_'+uid+ext
+    nd=odir+'/'+nf
+    '''
     if fdir=='':
         nd=nf
     else:
         nd=fdir+'/'+nf
+    '''
     #print('seqtk seq '+ingenome+' > '+nd)
     #exit()
     os.system('seqtk seq '+ingenome+' > '+nd)
@@ -1572,11 +1575,14 @@ def main():
     print('Please input the path of genomic sequence', flush=True) # print out message immediately
     input_pattern = args.mode
     input_genome_assembly_path = args.input_filename
-    input_genome_assembly_path= convert_ingenome(input_genome_assembly_path)
+    output_genome_assembly_path = args.output_filename
+    if not os.path.exists(output_genome_assembly_path):
+        os.makedirs(output_genome_assembly_path)
+    input_genome_assembly_path= convert_ingenome(input_genome_assembly_path,output_genome_assembly_path)
     #print(input_genome_assembly_path)
     #exit()
 
-    output_genome_assembly_path = args.output_filename
+    #output_genome_assembly_path = args.output_filename
     ensure_path(output_genome_assembly_path)
     #bfix=os.path.splitext(input_genome_assembly_path)[-1]
     pre=os.path.splitext(input_genome_assembly_path)[0]
@@ -1789,6 +1795,7 @@ def main():
     print('************************** AnnoSINE COMPLETE! **************************', flush=True)
     print('************************************************************************', flush=True)
     #os.system('rm -rf '+input_genome_assembly_path_dir)
+    os.system('rm '+input_genome_assembly_path)
 
 
 if __name__ == '__main__':
